@@ -1,4 +1,4 @@
-// Package cap provides the Linux Capabilities userspace library API
+// Package cap provides all the Linux Capabilities userspace library API
 // bindings in native Go.
 //
 // Capabilities are a feature of the Linux kernel that allow fine
@@ -59,6 +59,21 @@ const (
 	Inheritable
 )
 
+// String identifies a Flag value by its conventional "e", "p" or "i"
+// string abbreviation.
+func (f Flag) String() string {
+	switch f {
+	case Effective:
+		return "e"
+	case Permitted:
+		return "p"
+	case Inheritable:
+		return "i"
+	default:
+		return "<Error>"
+	}
+}
+
 // data holds a 32-bit slice of the compressed bitmaps of capability
 // sets as understood by the kernel.
 type data [Inheritable + 1]uint32
